package com.ruoyi.ibs.list.service;

import java.util.List;

import com.ruoyi.ibs.list.domain.CorporateShareholder;


/**
 * 企业，商户法人，关联经营人Service接口
 * 
 * @author ruoyi
 * @date 2024-10-29
 */
public interface ICorporateShareholderService 
{
    /**
     * 查询企业，商户法人，关联经营人
     * 
     * @param socialCreditCode 企业，商户法人，关联经营人主键
     * @return 企业，商户法人，关联经营人
     */
    public CorporateShareholder selectCorporateShareholderBySocialCreditCode(String socialCreditCode);

    /**
     * 查询企业，商户法人，关联经营人列表
     * 
     * @param corporateShareholder 企业，商户法人，关联经营人
     * @return 企业，商户法人，关联经营人集合
     */
    public List<CorporateShareholder> selectCorporateShareholderList(CorporateShareholder corporateShareholder);

    /**
     * 新增企业，商户法人，关联经营人
     * 
     * @param corporateShareholder 企业，商户法人，关联经营人
     * @return 结果
     */
    public int insertCorporateShareholder(CorporateShareholder corporateShareholder);

    /**
     * 修改企业，商户法人，关联经营人
     * 
     * @param corporateShareholder 企业，商户法人，关联经营人
     * @return 结果
     */
    public int updateCorporateShareholder(CorporateShareholder corporateShareholder);

    /**
     * 批量删除企业，商户法人，关联经营人
     * 
     * @param socialCreditCodes 需要删除的企业，商户法人，关联经营人主键集合
     * @return 结果
     */
    public int deleteCorporateShareholderBySocialCreditCodes(String[] socialCreditCodes);

    /**
     * 删除企业，商户法人，关联经营人信息
     * 
     * @param socialCreditCode 企业，商户法人，关联经营人主键
     * @return 结果
     */
    public int deleteCorporateShareholderBySocialCreditCode(String socialCreditCode);
}
